@@ -2,12 +2,14 @@ from __future__ import annotations
 
 import ast
 import os
+import sys
+from ast import Index
 from contextlib import suppress
 from importlib.util import find_spec
 from pathlib import Path
 from typing import TYPE_CHECKING
 
-from flake8_type_checking.codes import TC001, TC002, TC003, TC004, TC100, TC101, TC200, TC201
+from flake8_type_checking.codes import TC001, TC002, TC003, TC004, TC005, TC100, TC101, TC200, TC201
 
 possible_local_errors = ()
 with suppress(ModuleNotFoundError):
@@ -20,13 +22,15 @@ with suppress(ModuleNotFoundError):
     possible_local_errors += (AppRegistryNotReady, ImproperlyConfigured)  # type: ignore
 
 if TYPE_CHECKING:
-    from typing import Any, Generator, Optional, Union
+    from typing import Any, Generator, Optional, Tuple, Union
 
     ImportType = Union[ast.Import, ast.ImportFrom]
-    Flake8Generator = Generator[tuple[int, int, str, Any], None, None]
+    Flake8Generator = Generator[Tuple[int, int, str, Any], None, None]
 
 ATTRIBUTE_PROPERTY = 'flake8-type-checking_parent'
 
+py38 = sys.version_info.major == 3 and sys.version_info.minor == 8
+
 
 class ImportVisitor(ast.NodeTransformer):
     """Map all imports outside of type-checking blocks."""
@@ -73,6 +77,7 @@ class ImportVisitor(ast.NodeTransformer):
         self.futures_annotation: Optional[bool] = None
 
         # Where the type checking block exists (line_start, line_end, col_offset)
+        self.empty_type_checking_blocks: list[tuple[int, int, int]] = []
         self.type_checking_blocks: list[tuple[int, int, int]] = []
 
         # Function scopes can tell us if imports that appear in type-checking blocks
@@ -90,11 +95,22 @@ class ImportVisitor(ast.NodeTransformer):
         """Indicate whether an import is defined inside an `if TYPE_CHECKING` block or not."""
         if node.col_offset == 0:
             return False
-        if not self.type_checking_blocks:
+        if not self.type_checking_blocks and not self.empty_type_checking_blocks:
             return False
+
+        # The list of empty type checking blocks is maintained for TC005
+        # If we find an import within one of these, we simply move it into self.type_checking_blocks
+        for index, empty_type_checking_block in enumerate(list(self.empty_type_checking_blocks)):
+            if empty_type_checking_block[0] <= node.lineno <= empty_type_checking_block[1]:
+                if isinstance(node, (ast.Import, ast.ImportFrom)):
+                    self.type_checking_blocks.append(empty_type_checking_block)
+                    self.empty_type_checking_blocks.pop(index)
+                else:
+                    return True
+
         return any(
             type_checking_block[0] <= node.lineno <= type_checking_block[1]
-            for type_checking_block in self.type_checking_blocks
+            for type_checking_block in self.type_checking_blocks + self.empty_type_checking_blocks
         )
 
     def visit_If(self, node: ast.If) -> Any:
@@ -108,10 +124,16 @@ class ImportVisitor(ast.NodeTransformer):
                 # Just set the lineno of the first element in the else block - 1
                 start_of_else_block = node.orelse[0].lineno - 1
 
-            # Define range
-            self.type_checking_blocks.append(
-                (node.lineno, start_of_else_block or node.end_lineno or node.lineno, node.col_offset)
-            )
+            # empty_type_checking_blocks' items are moved to self.type_checking_blocks
+            # as soon as we discover an import within one of the "empty" blocks
+            if (node.end_lineno or node.lineno) - node.lineno == 1:
+                self.empty_type_checking_blocks.append(
+                    (node.lineno, start_of_else_block or node.end_lineno or node.lineno, node.col_offset)
+                )
+            else:
+                self.type_checking_blocks.append(
+                    (node.lineno, start_of_else_block or node.end_lineno or node.lineno, node.col_offset)
+                )
 
         self.generic_visit(node)
         return node
@@ -228,7 +250,7 @@ class ImportVisitor(ast.NodeTransformer):
         if self._in_type_checking_block(node):
             return node
         if hasattr(node, ATTRIBUTE_PROPERTY):
-            self.uses[f'{node.id}.{getattr(node, ATTRIBUTE_PROPERTY)}'] = node  # type: ignore
+            self.uses[f'{node.id}.{getattr(node, ATTRIBUTE_PROPERTY)}'] = node
         self.uses[node.id] = node
         return node
 
@@ -244,6 +266,8 @@ class ImportVisitor(ast.NodeTransformer):
     def _add_annotation(self, node: ast.AST) -> None:
         if isinstance(node, ast.Ellipsis):
             return
+        if py38 and isinstance(node, Index):
+            return self._add_annotation(node.value)  # type: ignore[attr-defined]
         if isinstance(node, ast.Constant):
             if node.value is None:
                 return
@@ -260,7 +284,7 @@ class ImportVisitor(ast.NodeTransformer):
         elif isinstance(node, (ast.Tuple, ast.List)):
             for n in node.elts:
                 self._add_annotation(n)
-        elif node is None:
+        elif node is None:  # noqa: SIM114
             return
         elif isinstance(node, ast.Attribute):
             self._add_annotation(node.value)
@@ -286,7 +310,7 @@ class ImportVisitor(ast.NodeTransformer):
         # This lets us read attribute names for `a.b.c` as `a.b.c` when we're treating the
         # `c` node, which is important to match attributes to imports
         with suppress(Exception):
-            parent = getattr(node, ATTRIBUTE_PROPERTY)  # type: ignore
+            parent = getattr(node, ATTRIBUTE_PROPERTY)
             node.attr = f'{node.attr}.{parent}'
         node = self._set_child_node_attribute(node, ATTRIBUTE_PROPERTY, node.attr)
         self.generic_visit(node)
@@ -360,6 +384,8 @@ class TypingOnlyImportsChecker:
             self.multiple_type_checking_blocks,
             # TC004
             self.used_type_checking_imports,
+            # TC005
+            self.empty_type_checking_blocks,
             # TC100
             self.missing_futures_import,
             # TC101
@@ -414,6 +440,11 @@ class TypingOnlyImportsChecker:
 
                 yield _import.lineno, 0, TC004.format(module=import_name), None
 
+    def empty_type_checking_blocks(self) -> Flake8Generator:
+        """TC005."""
+        for empty_type_checking_block in self.visitor.empty_type_checking_blocks:
+            yield empty_type_checking_block[0], 0, TC005, None
+
     def missing_futures_import(self) -> Flake8Generator:
         """TC100."""
         if (
